@@ -1,7 +1,7 @@
 /*
  * This file is part of bino, a 3D video player.
  *
- * Copyright (C) 2011, 2012
+ * Copyright (C) 2011, 2012, 2015
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,12 +25,12 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include "gettext.h"
-#define _(string) gettext(string)
+#include "base/exc.h"
+#include "base/str.h"
+#include "base/msg.h"
 
-#include "exc.h"
-#include "str.h"
-#include "msg.h"
+#include "base/gettext.h"
+#define _(string) gettext(string)
 
 #include "lirc.h"
 
