@@ -39,6 +39,10 @@
 # include <mach-o/dyld.h> // for _NSGetExecutablePath()
 #endif
 
+#if HAVE_LIBXNVCTRL
+# include <NVCtrl/NVCtrl.h>
+#endif // HAVE_LIBXNVCTRL
+
 #include <QCoreApplication>
 #include <QApplication>
 #include <QtGlobal>
@@ -63,10 +67,6 @@
 #endif
 #include "lib_versions.h"
 
-#if HAVE_LIBXNVCTRL
-#include "NVCtrl.h"
-#endif // HAVE_LIBXNVCTRL
-
 
 /* Return the directory containing our locale data (translated messages). */
 static const char *localedir()
@@ -558,6 +558,7 @@ int main(int argc, char *argv[])
     }
     if (version.value() || help.value())
     {
+        delete qt_app;
         return 0;
     }
 
