@@ -1,7 +1,7 @@
 /*
  * This file is part of bino, a 3D video player.
  *
- * Copyright (C) 2010, 2011, 2012, 2013
+ * Copyright (C) 2010, 2011, 2012, 2013, 2015
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -36,7 +36,7 @@
 # include <GL/glxew.h>
 #endif
 
-#include "thread.h"
+#include "base/pth.h"
 
 #include "video_output.h"
 
